@@ -126,6 +126,7 @@ class HydraHead(HydraThread):
                         # Fetch rows from database queue and claim items before processing
                         if not hydra_queue: time.sleep(options.hydra_sleep); continue
                         claimed = hydra_queue.claim()
+                        stdlib.logw(claimed, "CLAIMED HYDRA QUEUE: %s" % hydra_queue['hydra_queue_id'])
                         if not claimed: continue
                         hydra_type = aegis.model.HydraType.get_id(hydra_queue['hydra_type_id'])
                         # Hydra Magic: Find the hydra_type specific function in a subclass of HydraHead
@@ -191,6 +192,10 @@ class Hydra(HydraThread):
         if self.hydra_id == 0:
             logging.warning("%s clearing stale claims" % self.name)
             aegis.model.HydraQueue.clear_claims()
+            # If the hydra_type_id for this queue item has next_run_sql then it should be a singleton across the hydras.
+            # This means set hydra_type['status'] = 'running' and set it back to 'live' after completion.
+            logging.warning("%s clearing running jobs over 45 minutes old" % self.name)
+            aegis.model.HydraType.clear_running()
         try:
             self.spawn_heads()
             while(not HydraThread.quitting):
